pygrowthmodels
==============

.. image:: https://pyup.io/repos/github/drodriguezperez/pygrowthmodels/shield.svg
     :target: https://pyup.io/repos/github/drodriguezperez/pygrowthmodels/
     :alt: Updates

.. image:: https://travis-ci.org/drodriguezperez/pygrowthmodels.png
     :target: https://travis-ci.org/drodriguezperez/pygrowthmodels
     :alt: Latest Travis CI build status

.. image:: https://codecov.io/github/drodriguezperez/pygrowthmodels/coverage.svg?branch=master
     :target: https://codecov.io/github/drodriguezperez/pygrowthmodels?branch=master
     :alt: Codecov Code Coverage 

.. image:: https://img.shields.io/scrutinizer/g/drodriguezperez/pygrowthmodels.svg
     :target: https://scrutinizer-ci.com/g/drodriguezperez/pygrowthmodels/?branch=master
     :alt: Scrutinizer Code Quality


A compilation of nonlinear growth models

Features
--------
`pygrowthmodels` includes functions for the calculation of the following nonlinear growth models and its inverse functions:

* Blumberg
* Brody
* Chapman-Richards
* Generalised Logistic
* Generalised Richard
* Gompertz
* Janoschek
* Log-logistic
* Logistic
* Mitcherlich
* Monomolecular
* Morgan-Mercer-Flodin
* Negative exponential
* Richard’s
* Schnute
* Stannard
* von Bertalanffy
* Weibull

References
----------
1) D\. Fekedulegn, M\. Mac Siurtain, and J\. Colbert, "Parameter estimation of nonlinear growth models in forestry," Silva Fennica, vol. 33, no. 4, pp. 327-336, 1999. `[Full text #1]`_
2) M\. M\. Kaps, W\. O\. W\. Herring, and W\. R\. W\. Lamberson, "Genetic and environmental parameters for traits derived from the Brody growth curve and their relationships with weaning weight in Angus cattle.," Journal of Animal Science, vol. 78, no. 6, pp. 1436-1442, May 2000. `[Full text #2]`_
3) A\. Tsoularis and J\. Wallace, "Analysis of logistic growth models.," Math Biosci, vol. 179, no. 1, pp. 21–55, Jul. 2002. DOI identifier: `[10.1016/j.bbr.2011.03.031]`_
4) A\. Khamiz, Z\. Ismail, and A\. T\. Muhammad, "Nonlinear growth models for modeling oil palm yield growth," Journal of Mathematics and Statistics, vol. 1, no. 3, p. 225, 2005. DOI identifier: `[10.3844/jmssp.2005.225.233]`_
5) Michael J. Panik, "Growth Curve Modeling: Theory and Applications", John Wiley & Sons, December 2013.
6) Wikipedia contributors, "Generalised logistic function", Wikipedia, The Free Encyclopedia, 6 April 2018, 16:27 UTC, `[accessed 15 August 2004]`_

Disclaimer
----------
Copyright (C) 2018  Daniel Rodríguez Pérez

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

.. _`[Full text #1]`: http://www.metla.fi/silvafennica/full/sf33/sf334327.pdf
.. _`[Full text #2]`: http://www.ncbi.nlm.nih.gov/pubmed/10875624
.. _`[10.1016/j.bbr.2011.03.031]`: http://dx.doi.org/10.1016/j.bbr.2011.03.031
.. _`[10.3844/jmssp.2005.225.233]`: http://dx.doi.org/10.3844/jmssp.2005.225.233
.. _`[accessed 15 August 2004]`: https://en.wikipedia.org/w/index.php?title=Generalised_logistic_function&oldid=835109590
